==> id-broker-plugin_1.6.13.tar.gz: id-broker-plugin-1.6.13/performance-tests/performance_tests/keycloak/get_access_token_from_saml_session.py <==
import copy
import logging
import random
from typing import Dict, List

import requests
import requests.packages.urllib3
from locust import events, task
from urllib3.exceptions import InsecureRequestWarning

from performance_tests.common import TestData, get_schools, get_users_with_passwords
from performance_tests.keycloak.common import TestApp, TestAppError, get_saml_cookies_for_random_users

requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)

school_authorities: List[str] = []  # ["Traeger1", "Traeger"]
id_broker_school_users: Dict[str, Dict[str, Dict[str, str]]] = {}  # {sch_auth: {ou: {uid: uuid, ...}}}
id_broker_schools: Dict[str, Dict[str, str]] = {}  # {sch_auth: {ou: uuid, ...}}
NUM_SCHOOLS_PER_SCHOOL_AUTHORITY = 5  # loading all OUs from test DB takes to long
SAML_COOKIES_SAMPLE_SIZE = 100  # get this many SAML assertions before the test
saml_cookies: List[Dict[str, str]] = []  # ({cookie: RequestsCookieJar, traeger: traeger, user: user})


@events.init.add_listener
def on_init(environment, **kwargs):
    data = TestData()
    school_authorities.extend(data.school_authorities)
    id_broker_schools.update(get_schools(data))
    id_broker_school_users.update(get_users_with_passwords(data, NUM_SCHOOLS_PER_SCHOOL_AUTHORITY))
    saml_cookies.extend(
        get_saml_cookies_for_random_users(id_broker_school_users, samples=SAML_COOKIES_SAMPLE_SIZE)
    )


class TestAppClient(TestApp):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.saml_cookies = saml_cookies
        if not self.saml_cookies:
            raise Exception("NO saml cookies")
        self.url = f"https://{self.host}/{self.endpoint}"
        logging.debug("Testing with users: %r", self.saml_cookies)

    @task
    def access_token_get(self) -> None:
        sample = random.choice(self.saml_cookies)
        self.client.cookies = copy.deepcopy(sample["cookie"])

        # 1. univention-test-app/login
        params = {"kc_idp_hint": sample.get("idp_hint"), "pkce": "y"}
        with self.client.get(
            self.url,
            verify=False,
            params=params,
            name="univention-test-app/login",
            catch_response=True,
            allow_redirects=False,
        ) as response:
            try:
                redirect_url = response.headers["Location"]
            except KeyError as exc:
                response.failure(exc)
                return

        # 2. login.kc1.broker.local/auth/realms/ID-Broker/protocol/openid-connect/auth
        #    login.kc1.broker.local/auth/realms/ID-Broker/broker/traeger2/login
        name = "/auth/realms/ID-Broker/auth/login"
        with self.client.get(redirect_url, verify=False, catch_response=True, name=name) as response:
            try:
                saml_relay_state = self.extract_saml_relay_state(response.text)
                saml_request = self.extract_saml_request(response.text)
                redirect_url = self.extract_auth_redirect_url(response.text)
            except TestAppError as exc:
                response.failure(exc)
                return

        # 3. simplesamlphp/saml2/idp/SSOService.php
        data = {"SAMLRequest": saml_request, "RelayState": saml_relay_state}
        with self.client.post(redirect_url, verify=False, data=data, catch_response=True) as response:
            try:
                saml_response = self.extract_saml_response(response.text)
                saml_relay_state = self.extract_saml_relay_state(response.text)
                kc_redirect_url = self.extract_auth_redirect_url(response.text)
            except TestAppError as exc:
                response.failure(exc)
                return

        # 4. auth/realms/ID-Broker/broker/traeger1/endpoint
        data = {"SAMLResponse": saml_response, "RelayState": saml_relay_state}
        name = "/auth/realms/ID-Broker/broker/{traeger}/endpoint"
        with self.client.post(
            kc_redirect_url,
            name=name,
            data=data,
            verify=False,
            catch_response=True,
            allow_redirects=False,
        ) as response:
            try:
                location = response.headers["Location"]
            except (TestAppError, KeyError) as exc:
                response.failure(exc)
                return

        # 5. univention-test-app/authorize
        name = "univention-test-app/authorize"
        with self.client.get(location, name=name, verify=False, catch_response=True) as response:
            try:
                self.extrace_access_token(response.text)
            except TestAppError as exc:
                logging.exception(exc)
                logging.error(response.text)
                response.failure(exc)
                return

==> id-broker-plugin_2.3.0.tar.gz: id-broker-plugin-2.3.0/performance-tests/performance_tests/keycloak/get_access_token_from_saml_session.py <==
import copy
import logging
import random
from typing import Dict, List

import requests
import requests.packages.urllib3
from locust import events, task
from urllib3.exceptions import InsecureRequestWarning

from performance_tests.common import TestData, get_schools, get_users_with_passwords
from performance_tests.keycloak.common import (
    TestApp,
    TestAppError,
    get_saml_cookies_for_random_users,
)

requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)

school_authorities: List[str] = []  # ["Traeger1", "Traeger"]
id_broker_school_users: Dict[
    str, Dict[str, Dict[str, str]]
] = {}  # {sch_auth: {ou: {uid: uuid, ...}}}
id_broker_schools: Dict[str, Dict[str, str]] = {}  # {sch_auth: {ou: uuid, ...}}
NUM_SCHOOLS_PER_SCHOOL_AUTHORITY = 5  # loading all OUs from test DB takes to long
SAML_COOKIES_SAMPLE_SIZE = 100  # get this many SAML assertions before the test
saml_cookies: List[
    Dict[str, str]
] = []  # ({cookie: RequestsCookieJar, traeger: traeger, user: user})


@events.init.add_listener
def on_init(environment, **kwargs):
    data = TestData()
    school_authorities.extend(data.school_authorities)
    id_broker_schools.update(get_schools(data))
    id_broker_school_users.update(
        get_users_with_passwords(data, NUM_SCHOOLS_PER_SCHOOL_AUTHORITY)
    )
    saml_cookies.extend(
        get_saml_cookies_for_random_users(
            id_broker_school_users, samples=SAML_COOKIES_SAMPLE_SIZE
        )
    )


class TestAppClient(TestApp):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.saml_cookies = saml_cookies
        if not self.saml_cookies:
            raise Exception("NO saml cookies")
        self.url = f"https://{self.host}/{self.endpoint}"
        logging.debug("Testing with users: %r", self.saml_cookies)

    @task
    def access_token_get(self) -> None:
        sample = random.choice(self.saml_cookies)
        self.client.cookies = copy.deepcopy(sample["cookie"])

        # 1. univention-test-app/login
        params = {"kc_idp_hint": sample.get("idp_hint"), "pkce": "y"}
        with self.client.get(
            self.url,
            verify=False,
            params=params,
            name="univention-test-app/login",
            catch_response=True,
            allow_redirects=False,
        ) as response:
            try:
                redirect_url = response.headers["Location"]
            except KeyError as exc:
                response.failure(exc)
                return

        # 2. login.kc1.broker.local/auth/realms/ID-Broker/protocol/openid-connect/auth
        #    login.kc1.broker.local/auth/realms/ID-Broker/broker/traeger2/login
        name = "/auth/realms/ID-Broker/auth/login"
        with self.client.get(
            redirect_url, verify=False, catch_response=True, name=name
        ) as response:
            try:
                saml_relay_state = self.extract_saml_relay_state(response.text)
                saml_request = self.extract_saml_request(response.text)
                redirect_url = self.extract_auth_redirect_url(response.text)
            except TestAppError as exc:
                response.failure(exc)
                return

        # 3. simplesamlphp/saml2/idp/SSOService.php
        data = {"SAMLRequest": saml_request, "RelayState": saml_relay_state}
        with self.client.post(
            redirect_url, verify=False, data=data, catch_response=True
        ) as response:
            try:
                saml_response = self.extract_saml_response(response.text)
                saml_relay_state = self.extract_saml_relay_state(response.text)
                kc_redirect_url = self.extract_auth_redirect_url(response.text)
            except TestAppError as exc:
                response.failure(exc)
                return

        # 4. auth/realms/ID-Broker/broker/traeger1/endpoint
        data = {"SAMLResponse": saml_response, "RelayState": saml_relay_state}
        name = "/auth/realms/ID-Broker/broker/{traeger}/endpoint"
        with self.client.post(
            kc_redirect_url,
            name=name,
            data=data,
            verify=False,
            catch_response=True,
            allow_redirects=False,
        ) as response:
            try:
                location = response.headers["Location"]
            except (TestAppError, KeyError) as exc:
                response.failure(exc)
                return

        # 5. univention-test-app/authorize
        name = "univention-test-app/authorize"
        with self.client.get(
            location, name=name, verify=False, catch_response=True
        ) as response:
            try:
                self.extrace_access_token(response.text)
            except TestAppError as exc:
                logging.exception(exc)
                logging.error(response.text)
                response.failure(exc)
                return
